@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.124-3-gf9b7558
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.125-15-gfee1b85
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.125';
+our $VERSION = '0.126';
 
 use Moose;
 with
@@ -138,18 +138,22 @@ my %extra_args = (
 );
 
 # plugins that use the network when they run
-my @network_plugins = qw(
-    PromptIfStale
-    Test::Pod::LinkCheck
-    Test::Pod::No404s
-    Git::Remote::Check
-    CheckPrereqsIndexed
-    CheckIssues
-    UploadToCPAN
-    Git::Push
-);
-my %network_plugins;
-@network_plugins{ map { Dist::Zilla::Util->expand_config_package_name($_) } @network_plugins } = () x @network_plugins;
+sub _network_plugins
+{
+    my @network_plugins = qw(
+        PromptIfStale
+        Test::Pod::LinkCheck
+        Test::Pod::No404s
+        Git::Remote::Check
+        CheckPrereqsIndexed
+        CheckIssues
+        UploadToCPAN
+        Git::Push
+    );
+    my %network_plugins;
+    @network_plugins{ map { Dist::Zilla::Util->expand_config_package_name($_) } @network_plugins } = () x @network_plugins;
+    %network_plugins;
+}
 
 has _has_bash => (
     is => 'ro',
@@ -320,7 +324,7 @@ sub configure
         # we prefer this to run after other Register Prereqs plugins
         [ 'Git::Contributors'   => { ':version' => '0.029', order_by => 'commits' } ],
 
-        # note that MBT::*'s static tweak is consequently adjusted, later
+        # must appear after installers; also note that MBT::*'s static tweak is consequently adjusted, later
         [ 'StaticInstall'       => { ':version' => '0.005', mode => $static_install_mode, dry_run => $static_install_dry_run } ],
 
         # Test Runners (load after installers to avoid a rebuild)
@@ -339,7 +343,10 @@ sub configure
         [ 'CheckStrictVersion'  => { decimal_only => 1 } ],
         'CheckMetaResources',
         'EnsureLatestPerl',
-        [ 'Git::Check'          => 'initial check' => { allow_dirty => [''] } ],
+
+        # if in airplane mode, allow our uncommitted dist.ini edit which sets 'airplane = 1'
+        [ 'Git::Check'          => 'initial check' => { allow_dirty => [ $self->airplane ? '' : 'dist.ini' ] } ],
+
         'Git::CheckFor::MergeConflicts',
         [ 'Git::CheckFor::CorrectBranch' => { ':version' => '0.004', release_branch => 'master' } ],
         [ 'Git::Remote::Check'  => { branch => 'master', remote_branch => 'master' } ],
@@ -373,7 +380,7 @@ sub configure
 
         [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004', global => 1 } ],
         [ 'NextRelease'         => { ':version' => '5.033', time_zone => 'UTC', format => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
-        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/.*\.pm$', commit_msg => 'increment $VERSION after %v release' } ],
+        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => [ '^lib/.*\.pm$' ], commit_msg => 'increment $VERSION after %v release' } ],
         'Git::Push',
     );
 
@@ -385,6 +392,7 @@ sub configure
 
     if ($self->airplane)
     {
+        my %network_plugins = $self->_network_plugins;
         warn '[@Author::ETHER] ' . colored('building in airplane mode - plugins requiring the network are skipped, and releases are not permitted', 'yellow') . "\n";
         @plugins = grep {
             my $plugin = Dist::Zilla::Util->expand_config_package_name(
@@ -393,9 +401,6 @@ sub configure
             not exists $network_plugins{$plugin}
         } @plugins;
 
-        # allow our uncommitted dist.ini edit which sets 'airplane = 1'
-        push @{( first { ref eq 'ARRAY' && $_->[0] eq 'Git::Check' } @plugins )->[-1]{allow_dirty}}, 'dist.ini';
-
         # halt release after pre-release checks, but before ConfirmRelease
         push @plugins, 'BlockRelease';
     }
@@ -409,7 +414,8 @@ sub configure
     my $plugin_requirements = CPAN::Meta::Requirements->new;
     foreach my $plugin_spec (@plugins = map { ref $_ ? $_ : [ $_ ] } @plugins)
     {
-        next if $removed{$plugin_spec->[0]};
+        next if $removed{$plugin_spec->[0]}
+            or $plugin_spec->[0] eq 'BlockRelease';  # temporary hack, due to plugin ordering
 
         my $plugin = Dist::Zilla::Util->expand_config_package_name($plugin_spec->[0]);
         require_module($plugin);
@@ -417,17 +423,17 @@ sub configure
         push @$plugin_spec, {} if not ref $plugin_spec->[-1];
         my $payload = $plugin_spec->[-1];
 
-        if (my @modules_for_extra_configs = grep { $plugin->isa($_) or $plugin->does($_) } keys %extra_args)
+        foreach my $module (grep { $plugin->isa($_) or $plugin->does($_) } keys %extra_args)
         {
-            # combine all the relevant configs together
-            my %configs = map { %{ $extra_args{$_} } } @modules_for_extra_configs;
-
-            # and add to the payload for this plugin
-            @{$payload}{keys %configs} = values %configs;
+            my %configs = %{ $extra_args{$module} };    # copy, not reference!
 
             # don't keep :version unless it matches the package exactly, but still respect the prereq
-            $plugin_requirements->add_minimum($plugin => delete $configs{':version'})
-                if exists $configs{':version'} and not exists $extra_args{$plugin};
+            $plugin_requirements->add_minimum($module => delete $configs{':version'})
+                if exists $configs{':version'} and $module ne $plugin;
+
+            # we don't need to worry about overwriting the payload with defaults, as
+            # ConfigSlicer will copy them back over later on.
+            @{$payload}{keys %configs} = values %configs;
         }
 
         # record develop prereq
@@ -484,7 +490,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.125
+version 0.126
 
 =head1 SYNOPSIS
 
@@ -696,6 +702,11 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     -relationship = requires
     Dist::Zilla::PluginBundle::Author::ETHER = <version specified in dist.ini>
 
+    [Prereqs / prereqs for @Author::ETHER]
+    -phase = develop
+    -relationship = requires
+    ...all the plugins this bundle uses...
+
     [Prereqs / pluginbundle_version]
     -phase = develop
     -relationship = recommends
@@ -1032,16 +1043,18 @@ Available since 0.117.
 
 A string of the form C<cpan:PAUSEID> that references the PAUSE ID of the user who has primary ("first-come")
 authority over the distribution and main module namespace. If not provided, it is extracted from the configuration
-passed through to the <[Authority]|Dist::Zilla::Plugin::Authority> plugin, and finally defaults to C<cpan:ETHER>.
+passed through to the L<[Authority]|Dist::Zilla::Plugin::Authority> plugin, and finally defaults to C<cpan:ETHER>.
 It is presently used for setting C<x_authority> metadata and deciding which spelling is used for the F<LICENCE>
 file (if the C<licence> configuration is not provided).
 
 =head2 fake_release
 
+=for stopwords UploadToCPAN FakeRelease
+
 Available since 0.122.
 
-A boolean option that, when set, removes <[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN> from the plugin list
-and replaces it with <[FakeRelease]|Dist::Zilla::Plugin::FakeRelease>.
+A boolean option that, when set, removes L<[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN> from the plugin list
+and replaces it with L<[FakeRelease]|Dist::Zilla::Plugin::FakeRelease>.
 Defaults to false; can also be set with the environment variable C<FAKE_RELEASE>.
 
 =for stopwords customizations
